@@ -11,8 +11,10 @@ static const R_FortranMethodDef FortEntries[] = {
     {"cvpl_long",            (DL_FUNC) &F77_SUB(cvpl_long),            38},
 	{"cvplnl",            	(DL_FUNC) &F77_SUB(cvplnl),                45},
     {"frailpenal",           (DL_FUNC) &F77_SUB(frailpenal),           59},
+	{"frailpenalgen",           (DL_FUNC) &F77_SUB(frailpenalgen),           60},
     {"frailpred_sha_nor_mc", (DL_FUNC) &F77_SUB(frailpred_sha_nor_mc),  5},
     {"joint",                (DL_FUNC) &F77_SUB(joint),                65},
+	{"jointgen",                (DL_FUNC) &F77_SUB(jointgen),                65},
     {"joint_longi",          (DL_FUNC) &F77_SUB(joint_longi),          65},
 	{"jointlonginl",          (DL_FUNC) &F77_SUB(jointlonginl),	       62},
     {"joint_multiv",         (DL_FUNC) &F77_SUB(joint_multiv),         63},
